==> haskell-generic-trie-0.3.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-trie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generic-trie
version:              0.3.1
visibility:           public
id:                   generic-trie-0.3.1-9K6jeAujM7BLoG7D2yA3fW
key:                  generic-trie-0.3.1-9K6jeAujM7BLoG7D2yA3fW
license:              BSD-3-Clause
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             http://github.com/glguy/tries
synopsis:             A map, where the keys may be complex structured data.
description:
    This type implements maps where the keys are themselves
    complex structured data.  For example, the keys may be
    the abstract syntax trees for a programming language.
    The map is implemented as a trie, so common parts of the
    keys will be shared in the representation.  The library
    provides a generic implementation of the data structure,
    so values of types that have support for '\''Generic'\'' may
    be automatically used as keys in the map.

category:             Data
abi:                  29cc1d55eb90deabe5821ca207c64e76
exposed:              True
exposed-modules:      Data.GenericTrie Data.GenericTrie.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/generic-trie-0.3.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/generic-trie-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/generic-trie-0.3.1
hs-libraries:         HSgeneric-trie-0.3.1-9K6jeAujM7BLoG7D2yA3fW
depends:              base-4.14.1.0 containers-0.6.2.1 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-generic-trie/html/generic-trie.haddock

haddock-html:         /usr/share/doc/haskell-generic-trie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-trie-0.3.1-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-trie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generic-trie
version:              0.3.1
visibility:           public
id:                   generic-trie-0.3.1-Jv3TDywETCTCem5mpCscig
key:                  generic-trie-0.3.1-Jv3TDywETCTCem5mpCscig
license:              BSD-3-Clause
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             http://github.com/glguy/tries
synopsis:             A map, where the keys may be complex structured data.
description:
    This type implements maps where the keys are themselves
    complex structured data.  For example, the keys may be
    the abstract syntax trees for a programming language.
    The map is implemented as a trie, so common parts of the
    keys will be shared in the representation.  The library
    provides a generic implementation of the data structure,
    so values of types that have support for '\''Generic'\'' may
    be automatically used as keys in the map.

category:             Data
abi:                  b18b9389bc9aa3cc619748742678acb0
exposed:              True
exposed-modules:      Data.GenericTrie Data.GenericTrie.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/generic-trie-0.3.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/generic-trie-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/generic-trie-0.3.1
hs-libraries:         HSgeneric-trie-0.3.1-Jv3TDywETCTCem5mpCscig
depends:              base-4.15.0.0 containers-0.6.4.1 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-generic-trie/html/generic-trie.haddock

haddock-html:         /usr/share/doc/haskell-generic-trie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
